Ax Agent (Recommended)
======================

The ``blop.ax.Agent`` is the recommended agent interface that uses Ax as the backend for optimization and experiment tracking.

This agent provides a modern, maintainable interface for beamline optimization using the Ax optimization framework.

API Reference
-------------

.. autoclass:: blop.ax.Agent
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :no-index:
